@@ -175,6 +175,8 @@ marker_clicked_cb (ChamplainMarker *marker,
   gtk_widget_show (menu);
   gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL,
       event->button, event->time);
+  g_object_ref_sink (menu);
+  g_object_unref (menu);
 
   return FALSE;
 }
@@ -349,7 +351,7 @@ empathy_map_view_show (void)
 
   if (window)
     {
-      empathy_window_present (GTK_WINDOW (window->window), TRUE);
+      empathy_window_present (GTK_WINDOW (window->window));
       return window->window;
     }
 
@@ -413,7 +415,7 @@ empathy_map_view_show (void)
   model = GTK_TREE_MODEL (window->list_store);
   gtk_tree_model_foreach (model, map_view_contacts_foreach, window);
 
-  empathy_window_present (GTK_WINDOW (window->window), TRUE);
+  empathy_window_present (GTK_WINDOW (window->window));
 
   /* Set up time updating loop */
   window->timeout_id = g_timeout_add_seconds (5,
